@@ -34,5 +34,5 @@ from data.views.views import HardwareViewSet, AccessoryViewSet, CalibrationViewS
 # Wire up our API using automatic URL routing.
 # Additionally, we include login URLs for the browsable API.
 urlpatterns = [
-    path('/', include('data.urls')),
+    path('', include('data.urls')),
     ]
