@@ -539,7 +539,9 @@ class BaseInlineFormSetWithAddMoreButton(BaseInlineFormSet):
                     <div id="{empty_form_id}" style="display:none">
                     {empty_form_as_p}
                     </div>
-                    
+                    <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.3.1/jquery.min.js"></script>
+<script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.12.9/umd/popper.min.js"></script>
+<script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/js/bootstrap.min.js">
         <script>
     $('#{button_id}').click(function() {{
         var form_idx = $('#{self.prefix}-TOTAL_FORMS').val();
